@@ -654,9 +654,9 @@ namespace giac {
     if (args.type==_VECT)
       v=plotpreprocess(gen(*args._VECTptr,_SEQ__VECT),contextptr);
     else {
-      if (args==vx_var){ // special handling for x(t):=t^2; x'
+      if (args.type==_IDNT){ // special handling for x(t):=t^2; x'
 	gen tmp=eval(args,1,contextptr);
-	if (tmp!=vx_var)
+	if (tmp!=args)
 	  return _derive(tmp,contextptr);
       }
       v=plotpreprocess(makesequence(args,vx_var),contextptr);
@@ -808,6 +808,8 @@ namespace giac {
     step_infolevel(contextptr)=savestep;
     gprintf(step_extrema1,gettext("Derivative of %gen with respect to %gen is %gen\nSolving %gen with respect to %gen answer %gen"),makevecteur(arg,var,d,deq,var,s.type==_VECT?change_subtype(s,_SEQ__VECT):s),contextptr);
     calc_mode(c,contextptr);
+    if (c==1 && s.type==_VECT) 
+      s.subtype=0;
     vecteur ls=lidnt(s);
     for (int i=0;i<int(ls.size());++i){
       if (ls[i]==var || (var.type==_VECT && equalposcomp(*var._VECTptr,ls[i])))
@@ -949,7 +951,10 @@ namespace giac {
     if (lop(dg,at_derive).empty()){
       identificateur tmpi(" x");
       gen tmp(tmpi);
-      gen res=symb_program(tmp,zero,quotesubst(dg,_tmp,tmp,contextptr),contextptr);
+      _tmp=quotesubst(dg,_tmp,tmp,contextptr);
+      if (dg.type==_VECT)
+	_tmp=makevecteur(_tmp);
+      gen res=symb_program(tmp,zero,_tmp,contextptr);
       return res;
     }
     return symbolic(at_function_diff,g);
@@ -1030,7 +1035,7 @@ namespace giac {
       }
       if (u==at_asin || u==at_acos || u==at_atanh){
 	if (mode==1)
-	  excluded=mergevecteur(excluded,gen2vecteur(_solve(makesequence(symb_equal(pow(gf,2,contextptr),0),x),contextptr)));
+	  excluded=mergevecteur(excluded,gen2vecteur(_solve(makesequence(symb_equal(pow(gf,2,contextptr),1),x),contextptr)));
 	else
 	  eqs.push_back(symb_inferieur_egal(pow(gf,2,contextptr),1));
 	continue;
@@ -1107,10 +1112,30 @@ namespace giac {
     tmp.insert(tmp.begin(),symbolic(at_ou,gen(res,_SEQ__VECT)));
     return symbolic(at_and,gen(tmp,_SEQ__VECT));
   }
+  void domain_auto_assume(const gen & f,const gen & x,GIAC_CONTEXT){
+    vecteur range;
+    find_range(x,range,contextptr);
+    if (range.size()>=1 && range.front().type==_VECT){
+      range=*range.front()._VECTptr;
+      if (range.size()==2 && range[0]==minus_inf && range[1]==plus_inf){
+	gen periode;
+	if (is_periodic(f,x,periode,contextptr)){
+	  gen hyp=symb_and(symbolic(at_superieur_egal,makesequence(x,0)),symbolic(at_inferieur_egal,makesequence(x,periode)));
+	  *logptr(contextptr) << "Periodic function. Auto assume" << hyp << "\n";
+	  giac_assume(hyp,contextptr);
+	}
+      }
+    }
+  }
   gen _domain(const gen & args,GIAC_CONTEXT){
     if (is_undef(args)) return args;
-    if (args.type!=_VECT || args.subtype!=_SEQ__VECT)
-      return domain(args,vx_var,0,contextptr);
+    if (args.type!=_VECT || args.subtype!=_SEQ__VECT){
+      gen xval=assumeeval(vx_var,contextptr);
+      domain_auto_assume(args,vx_var,contextptr);
+      gen res=domain(args,vx_var,0,contextptr);
+      restorepurge(xval,vx_var,contextptr);
+      return res;
+    }
     vecteur v=*args._VECTptr;
     if (v.size()<2)
       return gensizeerr(contextptr);
@@ -1120,7 +1145,11 @@ namespace giac {
       v.push_back(0);
     if (v[2].type!=_INT_)
       return gensizeerr(contextptr);
-    return domain(v[0],v[1],v[2].val,contextptr);
+    gen xval=assumeeval(vx_var,contextptr);
+    domain_auto_assume(v[0],v[1],contextptr);
+    gen res=domain(v[0],v[1],v[2].val,contextptr);
+    restorepurge(xval,vx_var,contextptr);
+    return res;
   }
   static const char _domain_s []="domain";
   static define_unary_function_eval (__domain,&_domain,_domain_s);
