@@ -80,6 +80,7 @@ extern size_t stackptr;
 namespace giac {
 #endif // ndef NO_NAMESPACE_GIAC
 
+  size_t freeslotmem(); // non 0 if ALLOCSMALL is defined
   int sprint_int(char * s,int r);
   void sprint_double(char * s,double d);
 
@@ -645,7 +646,7 @@ namespace giac {
     // Pls do not use this constructor unless you know exactly what you do!!
     gen(ref_mpz_t * mptr);
 #ifdef DOUBLEVAL
-    gen(double d): type(_DOUBLE_),_DOUBLE_val(d) {};
+    inline gen(double d): type(_DOUBLE_),_DOUBLE_val(d) {};
 #else
     // may not work on ia64 with -O2
     gen(double d);
@@ -1274,6 +1275,7 @@ namespace giac {
       return s.c_str();
     }
     virtual std::string texprint (GIAC_CONTEXT) const { return "Nothing_to_print_tex"; }
+    virtual gen giac_constructor (GIAC_CONTEXT) const { return *this; }
     virtual gen eval(int level,const context * contextptr) const {return *this;};
     virtual gen evalf(int level,const context * contextptr) const {return *this;};
     virtual gen makegen(int i) const { return string2gen("makegen not redefined"); } ;
