@@ -276,6 +276,52 @@ namespace giac {
   bool is_python_builtin(const char * s){
     return dichotomic_search(python_builtins,sizeof(python_builtins)/sizeof(char*),s)!=-1;
   }
+  const char *js_keywords[]={ 
+    "Infinity",
+    "NaN", 
+    "break", 
+    "case", 
+    "catch",
+    "class", 
+    "const", 
+    "continue", 
+    "debugger",
+    "default",
+    "delete", 
+    "do", 
+    "else", 
+    "export", 
+    "extends",
+    "false", 
+    "finally",
+    "for", 
+    "function", 
+    "if", 
+    "import", 
+    "in", 
+    "instanceof",
+    "let",
+    "module", 
+    "new", 
+    "null", 
+    "return", 
+    "super",
+    "switch", 
+    "this", 
+    "throw", 
+    "true", 
+    "try", 
+    "typeof", 
+    "undefined", 
+    "var", 
+    "while",
+    "with",
+    "yield", 
+  };
+  bool is_js_keyword(const char * s){
+    return dichotomic_search(js_keywords,sizeof(js_keywords)/sizeof(char*),s)!=-1;
+  }
+
   
   // NB: cmd_name may be localized but related is not localized
   bool has_static_help(const char * & cmd_name,int lang,const char * & howto,const char * & syntax,const char * & related,const char * & examples){
@@ -307,14 +353,22 @@ namespace giac {
     kk=0;
 #ifdef MICROPY_LIB
     if (xcas_python_eval && !python_heap){
-      python_init(python_stack_size,python_heap_size);
+      python_init(pythonjs_stack_size,pythonjs_heap_size);
     }
 #endif
     for (;pos<static_help_size;++kk,++pos){
       const static_help_t & sh=static_help[pos];
       const char * ptr=sh.cmd_name;
+#ifdef QUICKJS
+      if (xcas_python_eval<0){
+	if (!js_token(ptr)){
+	  --kk;
+	  continue;
+	}
+      }
+#endif
 #ifdef MICROPY_LIB
-      if (xcas_python_eval){
+      if (xcas_python_eval>0){
 	if (!is_python_builtin(ptr) && mp_token(ptr)==0){
 	  --kk;
 	  continue;
@@ -516,7 +570,8 @@ namespace giac {
       of << "," << endl;
     }
     cmds << "]" << endl;
-    of << endl;
+    of << endl; 
+    of.close();
     ofstream ofw("static_help_w.h");
     ofstream ofwindex("index_w.h");
     ofwindex << "const TChooseItem index_w[]={" << endl;
@@ -1223,8 +1278,112 @@ namespace giac {
 #endif
 #endif // visualc
 
+#ifdef __MINGW_H
+  int giac_errno=0;
+  int get_errno(){
+    return giac_errno;
+  }
+  void set_errno(int i){
+    giac_errno=i;
+  }
+
+/* scandir.cc
+
+   Copyright 1998, 1999, 2000, 2001 Red Hat, Inc.
+
+   Written by Corinna Vinschen <corinna.vinschen@cityweb.de>
+
+   This file is part of Cygwin.
+
+   scandir is a copyrighted work licensed under the terms of the
+   Cygwin license.  Please consult the file "CYGWIN_LICENSE" for
+   details. */
+extern "C"
+int
+scandir (const char *dir,
+	 struct dirent ***namelist,
+	 int (*select) (const struct dirent *),
+	 int (*compar) (const struct dirent **, const struct dirent **))
+{
+  DIR *dirp;
+  struct dirent *ent, *etmp, **nl = NULL, **ntmp;
+  int count = 0;
+  int allocated = 0;
+
+  if (!(dirp = opendir (dir)))
+    return -1;
+
+  int prior_errno = get_errno ();
+  set_errno (0);
+
+  while ((ent = readdir (dirp)))
+    {
+      if (!select || select (ent))
+	{
+
+	  /* Ignore error from readdir/select. See POSIX specs. */
+	  set_errno (0);
+
+	  if (count == allocated)
+	    {
+
+	      if (allocated == 0)
+		allocated = 10;
+	      else
+		allocated *= 2;
+
+	      ntmp = (struct dirent **) realloc (nl, allocated * sizeof *nl);
+	      if (!ntmp)
+		{
+		  set_errno (ENOMEM);
+		  break;
+		}
+	      nl = ntmp;
+	  }
+
+	  if (!(etmp = (struct dirent *) malloc (sizeof *ent)))
+	    {
+	      set_errno (ENOMEM);
+	      break;
+	    }
+	  *etmp = *ent;
+	  nl[count++] = etmp;
+	}
+    }
+
+  if ((prior_errno = get_errno ()) != 0)
+    {
+      closedir (dirp);
+      if (nl)
+	{
+	  while (count > 0)
+	    free (nl[--count]);
+	  free (nl);
+	}
+      /* Ignore errors from closedir() and what not else. */
+      set_errno (prior_errno);
+      return -1;
+    }
+
+  closedir (dirp);
+  set_errno (prior_errno);
+
+  qsort (nl, count, sizeof *nl, (int (*)(const void *, const void *)) compar);
+  if (namelist)
+    *namelist = nl;
+  return count;
+}
+
+extern "C"
+int
+alphasort (const struct dirent **a, const struct dirent **b)
+{
+  return strcoll ((*a)->d_name, (*b)->d_name);
+}  
+#endif
+
   void find_all_index(const std::string & subdir,multimap<std::string,std::string> & mtt,multimap<std::string,std::string> & mall){
-#if defined GNUWINCE || defined __MINGW_H || defined __ANDROID__ || defined EMCC|| defined EMCC2 || defined NSPIRE_NEWLIB || defined FXCG || defined KHICAS
+#if defined GNUWINCE || defined __ANDROID__ || defined EMCC|| defined EMCC2 || defined NSPIRE_NEWLIB || defined FXCG || defined KHICAS
     return;
 #else
     // cerr << "HTML help Scanning " << subdir << endl;
@@ -1246,7 +1405,7 @@ namespace giac {
 
     struct dirent **eps;
     int n;
-#if defined APPLE_SMART || defined NO_SCANDIR
+#if defined APPLE_SMART || defined NO_SCANDIR 
     n =-1;
 #else
     n = scandir (subdir.c_str(), &eps, dir_select, alphasort);
