@@ -246,6 +246,7 @@ namespace giac {
    when all fork/child etc. will be removed */
   extern vecteur plot_instructions;
 #endif
+  extern bool gnuplot_opengl;
   int gnuplot_show_pnt(const symbolic & e,GIAC_CONTEXT);
 
   gen rationalparam2equation(const gen & at_orig,const gen & t_orig,const gen &x,const gen & y,GIAC_CONTEXT);
@@ -347,7 +348,7 @@ namespace giac {
 
   gen _cercle(const gen & args,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_cercle;
-  bool centre_rayon(const gen & cercle,gen & centre,gen & rayon,bool absrayon, GIAC_CONTEXT);
+  bool centre_rayon(const gen & cercle,gen & centre,gen & rayon,bool absrayon, GIAC_CONTEXT,bool detect_conic=false);
   gen _centre(const gen & args,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_centre;
   gen _rayon(const gen & args,GIAC_CONTEXT);
@@ -643,7 +644,7 @@ namespace giac {
   extern const unary_function_ptr * const  at_plotseq;
   extern const unary_function_ptr * const  at_seqplot;
 
-  gen plotimplicit(const gen& f_orig,const gen&x,const gen & y,double xmin,double xmax,double ymin,double ymax,int nxstep,int nystep,double eps,const vecteur & attributs,bool unfactored,const context * contextptr,int ckgeo2d);
+  gen plotimplicit(const gen& f_orig,const gen&x,const gen & y,double xmin,double xmax,double ymin,double ymax,int nxstep,int nystep,double eps,const vecteur & attributs,bool unfactored,bool cklinear,const context * contextptr,int ckgeo2d);
   gen _plotimplicit(const gen & args,GIAC_CONTEXT);
   extern const unary_function_ptr * const  at_plotimplicit;
   extern const unary_function_ptr * const  at_implicitplot;
