@@ -263,7 +263,9 @@
 {"add_language",13,9,0,0},
 {"additionally",13,9,0,0| 1},
 {"adjoint_matrix",13,9,0,0},
+{"affichage",13,9,0,0},
 {"affix",13,9,0,0},
+{"aire",13,9,0,0},
 {"alg",13,9,0,0},
 {"algsubs",13,9,0,0},
 {"algvar",13,9,0,0},
@@ -312,6 +314,7 @@
 {"autosimplify",13,9,0,0},
 {"avance",13,126,0,0},
 {"avgRC",13,9,0,0},
+{"axis",13,9,0,0},
 {"back",13,9,0,0},
 {"background",13,9,0,0| 1},
 {"backward",13,9,0,0},
@@ -319,6 +322,7 @@
 {"bar_plot",13,9,0,0},
 {"barplot",13,9,0,0},
 {"barycenter",13,9,0,0},
+{"barycentre",13,9,0,0},
 {"basis",13,9,0,0},
 {"batons",13,9,0,0},
 {"bernoulli",13,9,0,0},
@@ -336,6 +340,7 @@
 {"binomial_icdf",13,9,0,0},
 {"binprint",13,9,0,0},
 {"bisector",13,9,0,0},
+{"bissectrice",13,9,0,0},
 {"bitand",13,9,0,0},
 {"bitmap",13,9,0,0},
 {"bitor",13,9,0,0},
@@ -378,6 +383,8 @@
 {"center2interval",13,9,0,0},
 {"centered_cube",13,9,0,0},
 {"centered_tetrahedron",13,9,0,0},
+{"centre",13,9,0,0},
+{"cercle",13,9,0,0| 1},
 {"cfactor",13,9,0,0},
 {"cfsolve",13,9,0,0},
 {"changebase",13,9,0,0},
@@ -397,6 +404,7 @@
 {"chr",13,9,0,0},
 {"chrem",13,9,0,0},
 {"circle",13,9,0,0| 1},
+{"circonscrit",13,9,0,0},
 {"circumcircle",13,9,0,0},
 {"classes",13,9,0,0},
 {"clear",13,9,0,0},
@@ -429,6 +437,7 @@
 {"cone",13,9,0,0},
 {"confidence",13,9,0,0},
 {"conic",13,9,0,0},
+{"conique",13,9,0,0},
 {"conj",13,9,0,0},
 {"conjugate_gradient",13,9,0,0},
 {"cont",13,9,0,0| 1},
@@ -440,6 +449,7 @@
 {"convertir",13,9,0,0},
 {"convexhull",13,9,0,0},
 {"coordinates",13,9,0,0},
+{"coordonnees",13,9,0,0},
 {"copy",13,9,0,0},
 {"correlation",13,9,0,0},
 {"cos",13,9,0,0},
@@ -456,6 +466,7 @@
 {"courbe_polaire",13,9,0,0| 1},
 {"covariance",13,9,0,0},
 {"covariance_correlation",13,9,0,0},
+{"cp",13,9,0,0},
 {"cpartfrac",13,9,0,0},
 {"crationalroot",13,9,0,0},
 {"crayon",13,126,0,0},
@@ -509,6 +520,7 @@
 {"diag",13,9,0,0},
 {"diff",13,9,0,0| 1},
 {"dim",13,9,0,0},
+{"dir",13,9,0,0},
 {"display",13,9,0,0},
 {"disque",13,126,0,0},
 {"disque_centre",13,126,0,0},
@@ -525,6 +537,7 @@
 {"divisors",13,9,0,0},
 {"divmod",13,9,0,0},
 {"divpc",13,9,0,0},
+{"dodecaedre",13,9,0,0},
 {"dodecahedron",13,9,0,0},
 {"domain",13,9,0,0},
 {"dot",13,9,0,0},
@@ -533,12 +546,15 @@
 {"down",13,126,0,0},
 {"draw_arc",13,9,0,0},
 {"draw_circle",13,9,0,0},
+{"draw_filled_arc",13,9,0,0},
+{"draw_filled_circle",13,9,0,0},
 {"draw_line",13,9,0,0},
 {"draw_pixel",13,9,0,0},
 {"draw_polygon",13,9,0,0},
 {"draw_rectangle",13,9,0,0},
 {"draw_string",13,9,0,0},
 {"droit",13,9,0,0},
+{"droite",13,9,0,0| 1},
 {"droite_tangente",13,9,0,0},
 {"dsolve",13,9,0,0| 1},
 {"dtype",13,9,0,0},
@@ -642,6 +658,7 @@
 {"float",13,9,0,0},
 {"float2rational",13,9,0,0},
 {"floor",13,9,0,0},
+{"fmod",13,9,0,0},
 {"fonction",13,73,0,0| 1},
 {"fonction_derivee",13,9,0,0},
 {"fopen",13,9,0,0},
@@ -717,6 +734,7 @@
 {"harmonic_division",13,9,0,0| 1},
 {"has",13,9,0,0},
 {"hasard",13,77,0,0},
+{"hauteur",13,77,0,0},
 {"head",13,9,0,0},
 {"heading",13,9,0,0},
 {"heap_mult",13,9,0,0},
@@ -735,11 +753,13 @@
 {"hilbert",13,9,0,0},
 {"histogram",13,9,0,0},
 {"hold",13,9,0,0| 1},
+{"homothetie",13,9,0,0},
 {"homothety",13,9,0,0},
 {"horner",13,9,0,0},
 {"hp38",13,9,0,0},
 {"hyp2exp",13,9,0,0},
 {"hyperbola",13,9,0,0},
+{"hyperbole",13,9,0,0},
 {"hyperplan",13,9,0,0},
 {"hypersphere",13,9,0,0},
 {"hypersurface",13,9,0,0},
@@ -752,6 +772,7 @@
 {"ichinrem",13,9,0,0},
 {"ichrem",13,9,0,0},
 {"icontent",13,9,0,0},
+{"icosaedre",13,9,0,0},
 {"icosahedron",13,9,0,0},
 {"id",13,9,0,0},
 {"identity",13,9,0,0},
@@ -783,6 +804,7 @@
 {"innertln",13,9,0,0},
 {"input",13,9,0,0| 1},
 {"inputform",13,9,0,0| 1},
+{"inscrit",13,9,0,0},
 {"insert",13,9,0,0},
 {"insmod",13,9,0,0},
 {"int",13,9,0,0},
@@ -791,6 +813,7 @@
 {"integrate",13,9,0,0| 1},
 {"integrer",13,9,0,0},
 {"inter",13,9,0,0},
+{"inter_unique",13,9,0,0},
 {"interactive",13,9,0,0| 1},
 {"interactive_odeplot",13,9,0,0},
 {"interactive_plotode",13,9,0,0},
@@ -850,10 +873,9 @@
 {"join",13,9,0,0},
 {"jordan",13,9,0,0},
 {"jump",13,126,0,0},
-{"jusque",13,58,0,0| 1},
 {"ker",13,9,0,0},
 {"kernel",13,9,0,0},
-{"keyboard",13,9,0,0},
+{"keydown",13,9,0,0},
 {"kill",13,9,0,0},
 {"kolmogorovd",13,9,0,0},
 {"kolmogorovt",13,9,0,0},
@@ -910,6 +932,7 @@
 {"lname",13,9,0,0},
 {"lncollect",13,9,0,0},
 {"lnexpand",13,9,0,0},
+{"locate",13,9,0,0},
 {"locus",13,9,0,0| 1},
 {"log10",13,9,0,0},
 {"logarithmic_regression",13,9,0,0},
@@ -918,6 +941,7 @@
 {"logistic_regression",13,9,0,0},
 {"logistic_regression_plot",13,9,0,0},
 {"lower",13,9,0,0},
+{"ls",13,9,0,0},
 {"lsmod",13,9,0,0},
 {"lsq",13,9,0,0},
 {"lu",13,9,0,0},
@@ -948,19 +972,25 @@
 {"mean",13,9,0,0},
 {"median",13,9,0,0},
 {"median_line",13,9,0,0},
+{"mediane",13,9,0,0},
+{"mediatrice",13,9,0,0},
 {"member",13,9,0,0| 1},
 {"mgf",13,9,0,0},
 {"mid",13,9,0,0},
 {"midpoint",13,9,0,0},
+{"milieu",13,9,0,0},
 {"min",13,9,0,0},
 {"min_proba_time",13,9,0,0},
+{"mkdir",13,9,0,0},
 {"mkisom",13,9,0,0},
 {"mksa",13,9,0,0},
 {"modgcd",13,9,0,0},
 {"modgcd_cachesize",13,9,0,0},
 {"modp",13,9,0,0},
 {"mods",13,9,0,0},
+{"monotonic",13,9,0,0},
 {"montre_tortue",13,126,0,0},
+{"more",13,9,0,0},
 {"moustache",13,9,0,0},
 {"moyal",13,9,0,0},
 {"moyenne",13,9,0,0},
@@ -1008,6 +1038,7 @@
 {"nuage_points",13,9,0,0},
 {"nullspace",13,9,0,0},
 {"numer",13,9,0,0},
+{"octaedre",13,9,0,0},
 {"octahedron",13,9,0,0},
 {"octprint",13,9,0,0},
 {"odd",13,9,0,0},
@@ -1020,6 +1051,7 @@
 {"ord",13,9,0,0},
 {"order_size",13,9,0,0},
 {"ordinate",13,9,0,0},
+{"ordonnee",13,9,0,0},
 {"orthocenter",13,9,0,0},
 {"orthogonal",13,9,0,0},
 {"os_version",13,9,0,0},
@@ -1032,6 +1064,7 @@
 {"pade",13,9,0,0},
 {"padic_linsolve",13,9,0,0},
 {"parabola",13,9,0,0},
+{"parabole",13,9,0,0},
 {"parabolic_interpolate",13,9,0,0},
 {"parallel",13,9,0,0},
 {"parallelepiped",13,9,0,0},
@@ -1051,6 +1084,7 @@
 {"pd",13,126,0,0},
 {"pencolor",13,126,0,0},
 {"pendown",13,126,0,0},
+{"pente",13,9,0,0},
 {"penup",13,126,0,0},
 {"perimeter",13,9,0,0},
 {"perimeterat",13,9,0,0| 1},
@@ -1067,6 +1101,7 @@
 {"pivot",13,9,0,0},
 {"pixoff",13,9,0,0},
 {"pixon",13,9,0,0},
+{"plan",13,9,0,0},
 {"plane",13,9,0,0},
 {"plot",13,9,0,0| 1},
 {"plot3d",13,9,0,0},
@@ -1104,6 +1139,7 @@
 {"polyEval",13,9,0,0},
 {"polygamma",13,9,0,0},
 {"polygon",13,9,0,0},
+{"polygone",13,9,0,0},
 {"polygone_rempli",13,126,0,0},
 {"polygonplot",13,9,0,0},
 {"polygonscatterplot",13,9,0,0},
@@ -1198,9 +1234,13 @@
 {"rat_jordan_block",13,9,0,0},
 {"rationalroot",13,9,0,0},
 {"ratnormal",13,9,0,0},
+{"rayon",13,9,0,0},
 {"rdiv",13,9,0,0},
 {"re",13,9,0,0},
 {"read",13,77,0,0},
+{"read16",13,9,0,0},
+{"read32",13,9,0,0},
+{"read_nand",13,9,0,0},
 {"readrgb",13,9,0,0},
 {"readwav",13,9,0,0},
 {"real",13,9,0,0},
@@ -1247,6 +1287,7 @@
 {"rhs",13,9,0,0},
 {"right",13,9,0,0},
 {"right_triangle",13,9,0,0| 1},
+{"rm",13,9,0,0},
 {"rm_a_z",13,9,0,0},
 {"rm_all_vars",13,9,0,0},
 {"rmbreakpoint",13,9,0,0| 1},
@@ -1271,6 +1312,7 @@
 {"rpn",13,9,0,0},
 {"rref",13,9,0,0},
 {"rsolve",13,9,0,0| 1},
+{"saisir",13,9,0,0| 1},
 {"saute",13,126,0,0},
 {"sauve",13,126,0,0| 1},
 {"save_history",13,9,0,0},
@@ -1303,6 +1345,7 @@
 {"signature",13,9,0,0},
 {"signe",13,126,0,0},
 {"similarity",13,9,0,0},
+{"similitude",13,9,0,0},
 {"simp2",13,9,0,0},
 {"simplex_reduce",13,9,0,0},
 {"simplifier",13,9,0,0},
@@ -1320,6 +1363,7 @@
 {"size",13,9,0,0},
 {"sizes",13,9,0,0},
 {"skip",13,126,0,0},
+{"sleep",13,9,0,0},
 {"slope",13,9,0,0},
 {"slopeat",13,9,0,0| 1},
 {"slopeatraw",13,9,0,0},
@@ -1335,11 +1379,13 @@
 {"solve_zero_extremum",13,9,0,0| 1},
 {"somme",13,9,0,0| 1},
 {"sommet",13,9,0,0},
+{"sommets",13,9,0,0},
 {"sort",13,9,0,0},
 {"sorta",13,9,0,0},
 {"sortd",13,9,0,0},
 {"sorted",13,9,0,0},
 {"soundsec",13,9,0,0},
+{"speed",13,126,0,0},
 {"sphere",13,9,0,0},
 {"spherical2rectangular",13,9,0,0},
 {"spline",13,9,0,0},
@@ -1413,6 +1459,7 @@
 {"tcollectsin",13,9,0,0},
 {"testfunc",13,9,0,0},
 {"tests",13,9,0,0},
+{"tetraedre",13,9,0,0},
 {"tetrahedron",13,9,0,0},
 {"texpand",13,9,0,0},
 {"textinput",13,9,0,0| 1},
@@ -1423,6 +1470,7 @@
 {"total_degree",13,9,0,0},
 {"tourne_droite",13,126,0,0},
 {"tourne_gauche",13,126,0,0},
+{"towards",13,126,0,0},
 {"trace",13,9,0,0},
 {"tran",13,9,0,0},
 {"translation",13,9,0,0},
@@ -1459,12 +1507,15 @@
 {"valuation",13,9,0,0},
 {"vandermonde",13,9,0,0},
 {"variance",13,9,0,0},
+{"vecteur",13,9,0,0},
 {"vector",13,9,0,0},
 {"vers",13,126,0,0},
 {"version",13,9,0,0},
 {"vertices",13,9,0,0},
 {"vertices_abc",13,9,0,0},
 {"vertices_abca",13,9,0,0},
+{"vitesse_tortue",13,126,0,0},
+{"volume",13,9,0,0},
 {"vpotential",13,9,0,0| 1},
 {"warn_equal_in_prog",13,9,0,0},
 {"watch",13,9,0,0| 1},
@@ -1483,6 +1534,8 @@
 {"wilcoxont",13,9,0,0},
 {"with_sqrt",13,9,0,0},
 {"write",13,9,0,0| 1},
+{"write16",13,9,0,0},
+{"write32",13,9,0,0},
 {"writergb",13,9,0,0},
 {"writewav",13,9,0,0},
 {"wz_certificate",13,9,0,0},
